"""setup.py - builds py2exe executable for PB-Ball"""

import glob
import os.path
import shutil

from distutils.core import setup
import py2exe

origIsSystemDLL = py2exe.build_exe.isSystemDLL
def isSystemDLL(pathname):
    if os.path.basename(pathname).lower() in ("libfreetype-6.dll",
                                              "libogg-0.dll", "sdl_ttf.dll"):
        return 0
    return origIsSystemDLL(pathname)
py2exe.build_exe.isSystemDLL = isSystemDLL

from main import VERSION
if "a" in VERSION:
    VERSION = VERSION[:VERSION.index("a")]
elif "b" in VERSION:
    VERSION = VERSION[:VERSION.index("b")]

if os.path.isdir("dist"):
    shutil.rmtree("dist")
setup(options={"py2exe": {"compressed": 1,
                          "optimize": 2,
                          "bundle_files": 1,
                          "includes": ["pygame._view"],
                          "excludes": ["_gtkagg", "_tkagg", "bsddb", "curses",
                                       "email", "pywin.debugger",
                                       "pywin.debugger.dbgcon",
                                       "pywin.dialogs", "tcl", "Tkconstants",
                                       "Tkinter", "_ssl", "doctest", "pdb",
                                       "unittest", "difflib", "inspect"],
                          "dll_excludes": ["libgdk-win32-2.0-0.dll",
                                           "libgobject-2.0-0.dll", "tcl84.dll",
                                           "tk84.dll", "msvcp90.dll",
                                           "w9xpopen.exe"]}},
      windows=[{"script": "pb-ball.py",
                "name": "PB-Ball",
                "version": VERSION,
                "company_name": "Timothy Johnson",
                "copyright": "Copyright \xa9 2015 Timothy Johnson",
                "description": "Python Basketball Game",
                "icon_resources": [(1, "images\\pb-ball.ico")]}],
      data_files=[("fonts", glob.glob("fonts\\*")),
                  ("images", ["images\\ball.png", "images\\icon.png"]),
                  ("sounds", glob.glob("sounds\\*.*")),
                  ("", ["credits.txt", "license.txt"])],
      zipfile=None)
thumbs_db = os.path.join("dist", "images", "Thumbs.db")
if os.path.isfile(thumbs_db):  # Remove WinXP thumbnail caches in dist dir
    os.remove(thumbs_db)
